package tech.sbdevelopment.websiteExample.examples;

import nl.sbdeveloper.vehiclesplus.api.VehiclesPlusAPI;
import nl.sbdeveloper.vehiclesplus.api.events.impl.VehicleDespawnEvent;
import nl.sbdeveloper.vehiclesplus.api.vehicles.Vehicle;
import nl.sbdeveloper.vehiclesplus.api.vehicles.impl.SpawnedVehicle;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

import java.util.Comparator;
import java.util.List;
import java.util.Optional;

public class DespawnVehicle {
    /**
     * Despawns the first spawned vehicle of a player.
     * If the player has multiple spawned vehicles, this method will despawn the first one retrieved.
     *
     * @param player The player whose vehicle is to be despawned.
     */
    public void despawnFirstVehicle(Player player) {
        // Retrieve the first spawned vehicle of the player
        Optional<SpawnedVehicle> firstSpawnedVehicleOptional = VehiclesPlusAPI.getVehicle(player);

        // Check if a vehicle is present to despawn
        if (firstSpawnedVehicleOptional.isPresent()) {
            // Despawn the vehicle using the API's despawn reason
            firstSpawnedVehicleOptional.get().despawn(VehicleDespawnEvent.DespawnReason.API);
            System.out.println("Vehicle despawned successfully.");
        } else {
            // Handle the case where the player doesn't have a spawned vehicle
            System.err.println("Player does not have a spawned vehicle.");
        }
    }

    /**
     * Despawns the closest spawned vehicle to the executor player.
     * The executor player is the one determining which vehicle is closest to them.
     *
     * @param executor The player who is looking for the closest vehicle to despawn.
     * @param targetPlayer The player whose vehicles will be checked.
     */
    public void despawnClosestVehicle(Player executor, Player targetPlayer) {
        // Retrieve a list of all spawned vehicles belonging to the target player
        @NotNull List<Vehicle> vehiclesOfTargetPlayer = VehiclesPlusAPI.getVehicles(targetPlayer);

        // Find the closest spawned vehicle to the executor player
        Optional<SpawnedVehicle> closestVehicleOptional = vehiclesOfTargetPlayer.stream()
                .filter(vehicle -> vehicle instanceof SpawnedVehicle) // Only consider spawned vehicles
                .map(vehicle -> (SpawnedVehicle) vehicle)
                .min(Comparator.comparingDouble(vehicle -> vehicle.getHolder().getLocation().distance(executor.getLocation())));

        // Check if the closest vehicle was found
        if (closestVehicleOptional.isPresent()) {
            // Despawn the closest vehicle using the API's despawn reason
            closestVehicleOptional.get().despawn(VehicleDespawnEvent.DespawnReason.API);
            System.out.println("Closest vehicle despawned successfully.");
        } else {
            // Handle the case where no spawned vehicles are found for the target player
            System.err.println("Target player does not have any spawned vehicles.");
        }
    }
}
