package tech.sbdevelopment.websiteExample.examples;

import nl.sbdeveloper.vehiclesplus.api.VehiclesPlusAPI;
import nl.sbdeveloper.vehiclesplus.api.garages.Garage;
import nl.sbdeveloper.vehiclesplus.api.vehicles.impl.StorageVehicle;
import org.bukkit.entity.Player;

public class GiveVehicle {

    /**
     * Gives a vehicle to a specific garage.
     * Attempts to create a vehicle of the specified type and add it to the provided garage.
     *
     * @param targetGarage The garage where the vehicle will be stored.
     * @param vehicleType The type of vehicle to be created.
     */
    public void giveVehicleToGarage(Garage targetGarage, String vehicleType) {
        // Attempt to create a new vehicle of the given type
        StorageVehicle createdVehicle = VehiclesPlusAPI.createVehicle(vehicleType);

        // If vehicle creation fails, log the error and exit
        if (createdVehicle == null) {
            System.err.println("Failed to create vehicle of type: " + vehicleType);
            return; // Exit if the vehicle could not be created
        }

        // Add the created vehicle's UUID to the target garage
        targetGarage.addVehicle(createdVehicle.getUuid());
        System.out.println("Vehicle created and added to the garage successfully.");
    }

    /**
     * Gives a vehicle to the player's default garage.
     * Attempts to create a vehicle of the specified type and add it to the player's personal garage.
     *
     * @param player The player whose default garage will receive the vehicle.
     * @param vehicleType The type of vehicle to be created.
     */
    public void giveVehicleToPlayerGarage(Player player, String vehicleType) {
        // Attempt to create a new vehicle of the given type
        StorageVehicle createdVehicle = VehiclesPlusAPI.createVehicle(vehicleType);

        // Retrieve the player's personal garage (will create a new garage if none exists)
        Garage playerGarage = VehiclesPlusAPI.getPersonalGarage(player);

        // If vehicle creation fails, log the error and exit
        if (createdVehicle == null) {
            System.err.println("Failed to create vehicle of type: " + vehicleType);
            return; // Exit if the vehicle could not be created
        }

        // Add the created vehicle's UUID to the player's personal garage
        playerGarage.addVehicle(createdVehicle.getUuid());
        System.out.println("Vehicle created and added to the player's personal garage successfully.");
    }
}
